@@ -45,8 +45,8 @@
 
 
 // KDE includes
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include "kfourinline_debug.h"
 
 
 
@@ -86,16 +86,19 @@ DisplayIntro::DisplayIntro(QGraphicsScene* scene, ThemeManager* theme, QGraphics
   mQuickLaunch = new PixmapSprite("quicklaunch", mTheme, 0, mScene);
   mSprites.append(mQuickLaunch);
   mQuickLaunch->show();
-  mTextQuicklaunch = new QGraphicsTextItem(mQuickLaunch, scene);
+  mTextQuicklaunch = new QGraphicsTextItem(mQuickLaunch);
+  scene->addItem(mTextQuicklaunch);
   mTextQuicklaunch->setPlainText(i18nc("Name of quicklaunch field", "Quick Launch"));
   QTextDocument* text_document = mTextQuicklaunch->document();
   text_document->setDefaultTextOption(QTextOption(Qt::AlignHCenter));
   mTextQuicklaunch->setDocument(text_document);
   mTextQuicklaunch->show();
-  mTextStartplayer = new QGraphicsTextItem(mQuickLaunch, scene);
+  mTextStartplayer = new QGraphicsTextItem(mQuickLaunch);
+  scene->addItem(mTextStartplayer);
   mTextStartplayer->setPlainText(i18nc("Ask player who should start game", "Who starts?"));
   mTextStartplayer->show();
-  mTextColor = new QGraphicsTextItem(mQuickLaunch, scene);
+  mTextColor = new QGraphicsTextItem(mQuickLaunch);
+  scene->addItem(mTextColor);
   mTextColor->setPlainText(i18nc("Ask player which color he wants to play", "Your color?"));
   mTextColor->show();
 
@@ -175,11 +178,11 @@ DisplayIntro::DisplayIntro(QGraphicsScene* scene, ThemeManager* theme, QGraphics
 
   // Animation timer
   mTimer = new QTimer(this);
-  connect(mTimer, SIGNAL(timeout()), this, SLOT(advance()));
+  connect(mTimer, &QTimer::timeout, this, &DisplayIntro::advance);
 
   // Redraw
   if (theme) theme->updateTheme(this);
-  kDebug() << "CONSTRUCTOR DONE";
+  qCDebug(KFOURINLINE_LOG) << "CONSTRUCTOR DONE";
 }
 
 
@@ -188,7 +191,7 @@ void DisplayIntro::buttonPressed(QGraphicsItem* item, int id)
 {
   int status = id >> 8;
   int no = id & 0xff;
-  //kDebug() << "Button" << no  << "pressed status="<<status;
+  //qCDebug(KFOURINLINE_LOG) << "Button" << no  << "pressed status="<<status;
   ButtonSprite* button = dynamic_cast<ButtonSprite*>(item);
   Q_ASSERT(button);
   if (button == mStartButton[0])
@@ -256,7 +259,7 @@ DisplayIntro::~DisplayIntro()
 // Master theme change function. Redraw the display
 void DisplayIntro::changeTheme()
 {
-  kDebug() << "THEME CHANGE " << thememanager()->themefileChanged();
+  qCDebug(KFOURINLINE_LOG) << "THEME CHANGE " << thememanager()->themefileChanged();
   // Measure time for resize
   QTime time;
   time.restart();
@@ -346,7 +349,7 @@ void DisplayIntro::changeTheme()
                      posColor.y() * height + (textHeight - bounding.height()) / 2);
 
   int elapsed = time.elapsed();
-  kDebug() << "THEME CHANGE took " << elapsed << " ms";
+  qCDebug(KFOURINLINE_LOG) << "THEME CHANGE took " << elapsed << " ms";
 
   // Renew animation on theme change?
   if (thememanager()->themefileChanged())
@@ -363,7 +366,7 @@ void DisplayIntro::changeTheme()
 // Start the animation
 void DisplayIntro::start(int delay)
 {
-  kDebug() << "START TIMER";
+  qCDebug(KFOURINLINE_LOG) << "START TIMER";
   // Do the timer
   mTimer->stop();
   mTimer->setSingleShot(true);
@@ -394,7 +397,7 @@ void DisplayIntro::advance()
   time.restart();
   int duration = createAnimation(true);
 
-  kDebug() << "ADVANCE: Restarting timer in " << (duration+5000) <<" creation time " << time.elapsed();
+  qCDebug(KFOURINLINE_LOG) << "ADVANCE: Restarting timer in " << (duration+5000) <<" creation time " << time.elapsed();
   mTimer->start(duration + 5000);  // [ms]
 }
 
@@ -616,4 +619,4 @@ void DisplayIntro::viewEvent(QEvent* event)
 
 }
 
-#include "displayintro.moc"
+
