@@ -33,15 +33,12 @@
 #include <QTimer>
 #include <QKeyEvent>
 #include <QList>
-#include <QMouseEvent>
 
 // include files for KDE
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+
+#include "kfourinline_debug.h"
 #include <krandomsequence.h>
-#include <kglobal.h>
-#include <kcomponentdata.h>
 
 // application specific includes
 #include "kwin4view.h"
@@ -50,6 +47,7 @@
 #include "score.h"
 #include "ui_statuswidget.h"
 #include <config-src.h>
+#include <QStandardPaths>
 
 
 #define FIELD_SIZE_X 7
@@ -60,14 +58,13 @@ KWin4Doc::KWin4Doc(QWidget *parent) : KGame(1234,parent), pView(0), mHintProcess
 {
   mStatus = new Score(parent);
 
-  connect(this,SIGNAL(signalPropertyChanged(KGamePropertyBase*,KGame*)),
-          this,SLOT(gamePropertyChanged(KGamePropertyBase*,KGame*)));
+  connect(this, &KWin4Doc::signalPropertyChanged, this, &KWin4Doc::gamePropertyChanged);
 
   dataHandler()->Debug();
-  //kDebug(12010) << "Property 7 policy=" << dataHandler()->find(7)->policy();
+  //qCDebug(KFOURINLINE_LOG) << "Property 7 policy=" << dataHandler()->find(7)->policy();
   setPolicy(KGame::PolicyDirty,true);
 
-  //kDebug(12010) << "Property 7 policy=" << dataHandler()->find(7)->policy();
+  //qCDebug(KFOURINLINE_LOG) << "Property 7 policy=" << dataHandler()->find(7)->policy();
 
   // Game design
   setMaxPlayers(2);
@@ -104,7 +101,7 @@ KWin4Doc::KWin4Doc(QWidget *parent) : KGame(1234,parent), pView(0), mHintProcess
   mStartPlayer=Yellow;
   mStartPlayer.registerData(dataHandler(),KGamePropertyBase::PolicyDirty,QString("mStartPlayer"));
   setCurrentPlayer((COLOUR)mStartPlayer.value()); 
-  if (global_debug>1) kDebug(12010) << "amZug policy=" << mAmzug.policy();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "amZug policy=" << mAmzug.policy();
 
   mPlayedBy[Yellow] = KGameIO::MouseIO;
   mPlayedBy[Red]    = KGameIO::MouseIO;
@@ -119,10 +116,8 @@ KWin4Doc::KWin4Doc(QWidget *parent) : KGame(1234,parent), pView(0), mHintProcess
   setGameStatus(Intro);
 
   // Listen to network
-  connect(this,SIGNAL(signalMessageUpdate(int,quint32,quint32)),
-         this,SLOT(networkMessageUpdate(int,quint32,quint32)));
-  connect(this,SIGNAL(signalClientJoinedGame(quint32,KGame*)),
-         this,SLOT(clientConnected(quint32,KGame*)));
+  connect(this, &KWin4Doc::signalMessageUpdate, this, &KWin4Doc::networkMessageUpdate);
+  connect(this, &KWin4Doc::signalClientJoinedGame, this, &KWin4Doc::clientConnected);
 
   // Change global KGame policy
   //dataHandler()->setPolicy(KGamePropertyBase::PolicyDirty,false);
@@ -133,10 +128,10 @@ KWin4Doc::KWin4Doc(QWidget *parent) : KGame(1234,parent), pView(0), mHintProcess
 // Destructor
 KWin4Doc::~KWin4Doc()
 {
-  kDebug() << "~KWin4Doc()";
+  qCDebug(KFOURINLINE_LOG) << "~KWin4Doc()";
   delete mHintProcess;
   delete mStatus;
-  kDebug() << "~KWin4Doc() done";
+  qCDebug(KFOURINLINE_LOG) << "~KWin4Doc() done";
 }
 
 
@@ -163,7 +158,7 @@ void KWin4Doc::initPlayers()
 void KWin4Doc::setView(KWin4View *view)
 {
   pView=view;
-  connect(pView, SIGNAL(signalMoveDone(int)), this, SLOT(moveDone(int)));
+  connect(pView, &KWin4View::signalMoveDone, this, &KWin4Doc::moveDone);
 }
 
 
@@ -179,7 +174,7 @@ void KWin4Doc::setColour(int x,int y,COLOUR c)
 {
   if (x<0 || x>=FIELD_SIZE_X || y<0 || y>=FIELD_SIZE_Y)
   {
-    kFatal(12010) << "ERROR: setColour on wrong position" << x << " " << y;
+    qCCritical(KFOURINLINE_LOG) << "ERROR: setColour on wrong position" << x << " " << y;
     return ;
   }
   mField.setAt(x+y*FIELD_SIZE_X,c);
@@ -223,7 +218,7 @@ void KWin4Doc::resetGame(bool initview)
 void KWin4Doc::activateCurrentPlayer()
 {
   if (global_debug>1)
-    kDebug(12010) << "Setting the current player to turn";
+    qCDebug(KFOURINLINE_LOG) << "Setting the current player to turn";
   getPlayer(getCurrentPlayer())->setTurn(true,true);
 }
 
@@ -278,7 +273,7 @@ void KWin4Doc::moveDone(int /*mode*/ )
 KPlayer* KWin4Doc::nextPlayer(KPlayer* last, bool /*exclusive*/)
 {
   if (global_debug>1)
-     kDebug(12010) << "nextPlayer last="<<last->id() << "admin=" << isAdmin();
+     qCDebug(KFOURINLINE_LOG) << "nextPlayer last="<<last->id() << "admin=" << isAdmin();
 
   // Should be enough if the admin sets the turn
   if (last->userId()==Yellow)
@@ -286,7 +281,7 @@ KPlayer* KWin4Doc::nextPlayer(KPlayer* last, bool /*exclusive*/)
   else
     setCurrentPlayer(Yellow);
   if (global_debug>1)
-    kDebug(12010) <<" Current set to "<<getCurrentPlayer();
+    qCDebug(KFOURINLINE_LOG) <<" Current set to "<<getCurrentPlayer();
   if (isAdmin())
     getPlayer(getCurrentPlayer())->setTurn(true,true);
   emit signalNextPlayer(int(getCurrentPlayer()));
@@ -299,7 +294,7 @@ KPlayer* KWin4Doc::nextPlayer(KPlayer* last, bool /*exclusive*/)
 bool KWin4Doc::doMove(int x,int id)
 {
   if (global_debug>1)
-    kDebug(12010) <<" KWin4Doc::Move pos="<<x<<" id="<<id<<" ";
+    qCDebug(KFOURINLINE_LOG) <<" KWin4Doc::Move pos="<<x<<" id="<<id<<" ";
 
   return (makeMove(x,0) == GNormal);
 }
@@ -311,7 +306,7 @@ MOVESTATUS KWin4Doc::makeMove(int x, int mode)
 {
   if (x<0 || x>=FIELD_SIZE_X)
   {
-    kDebug(12010) << "ERROR: makeMove auf falsche Position" << x;
+    qCDebug(KFOURINLINE_LOG) << "ERROR: makeMove auf falsche Position" << x;
     return GNotAllowed;
   }
 
@@ -371,12 +366,12 @@ bool KWin4Doc::undoMove()
     setColour(mLastHint,hy,Nobody);
     mLastHint=-1;
   }
-  // kDebug(12010) << "Undo no="<<mHistoryCnt.value();
+  // qCDebug(KFOURINLINE_LOG) << "Undo no="<<mHistoryCnt.value();
   mHistoryCnt=mHistoryCnt.value()-1;
   int x=mHistory.at(getHistoryCnt());
   mFieldFilled.setAt(x,mFieldFilled.at(x)-1);
   int y=mFieldFilled.at(x);
-  // kDebug(12010) << "Undo x="<<x << "y=" <<y;
+  // qCDebug(KFOURINLINE_LOG) << "Undo x="<<x << "y=" <<y;
   setColour(x,y,Nobody);
   // We have to remove the piece as well...
 
@@ -412,7 +407,7 @@ bool KWin4Doc::redoMove()
   if (getHistoryCnt()>=mMaxMove) return false;
   
   int x=mHistory.at(getHistoryCnt());
-  //kDebug(12010) << "Redo x=" << x;
+  //qCDebug(KFOURINLINE_LOG) << "Redo x=" << x;
   makeMove(x,1);
   if (getCurrentPlayer()==Yellow)
     setCurrentPlayer(Red);
@@ -478,7 +473,7 @@ COLOUR KWin4Doc::getPlayerColour(int player){
 int KWin4Doc::checkGameOver(KPlayer* p)
 {
   if (global_debug>1)
-    kDebug(12010) <<"KWin4Doc::checkGameOver::"<<p->userId();
+    qCDebug(KFOURINLINE_LOG) <<"KWin4Doc::checkGameOver::"<<p->userId();
   return checkGameOver(mLastColumn ,(COLOUR)(mLastColour.value()));
 }
 
@@ -692,20 +687,20 @@ void KWin4Doc::setScore(long value)
 // Load settings from Prefs
 void KWin4Doc::loadSettings()
 {
-  kDebug() << "++++ KWin4Doc::loadSettings() ";
-  kDebug() << "Level:" << Prefs::level();
-  kDebug() << "Name:" << Prefs::name1();
-  kDebug() << "Name2:" << Prefs::name2();
-  kDebug() << "input0mouse:" << Prefs::input0mouse();
-  kDebug() << "input0key:" << Prefs::input0key();
-  kDebug() << "input0ai:" << Prefs::input0ai();
-  kDebug() << "input1mouse:" << Prefs::input1mouse();
-  kDebug() << "input1key:" << Prefs::input1key();
-  kDebug() << "input1ai:" << Prefs::input1ai();
-  kDebug() << "start red:"   << Prefs::startcolourred();
-  kDebug() << "start yellow" << Prefs::startcolouryellow();
-  kDebug() << "Learning     " << Prefs::learning();
-  kDebug() << "Lock         " << Prefs::ailock();
+  qCDebug(KFOURINLINE_LOG) << "++++ KWin4Doc::loadSettings() ";
+  qCDebug(KFOURINLINE_LOG) << "Level:" << Prefs::level();
+  qCDebug(KFOURINLINE_LOG) << "Name:" << Prefs::name1();
+  qCDebug(KFOURINLINE_LOG) << "Name2:" << Prefs::name2();
+  qCDebug(KFOURINLINE_LOG) << "input0mouse:" << Prefs::input0mouse();
+  qCDebug(KFOURINLINE_LOG) << "input0key:" << Prefs::input0key();
+  qCDebug(KFOURINLINE_LOG) << "input0ai:" << Prefs::input0ai();
+  qCDebug(KFOURINLINE_LOG) << "input1mouse:" << Prefs::input1mouse();
+  qCDebug(KFOURINLINE_LOG) << "input1key:" << Prefs::input1key();
+  qCDebug(KFOURINLINE_LOG) << "input1ai:" << Prefs::input1ai();
+  qCDebug(KFOURINLINE_LOG) << "start red:"   << Prefs::startcolourred();
+  qCDebug(KFOURINLINE_LOG) << "start yellow" << Prefs::startcolouryellow();
+  qCDebug(KFOURINLINE_LOG) << "Learning     " << Prefs::learning();
+  qCDebug(KFOURINLINE_LOG) << "Lock         " << Prefs::ailock();
 
 
   // Store level for score sprite display
@@ -720,26 +715,26 @@ void KWin4Doc::loadSettings()
   if(Prefs::input0mouse())      mode = KGameIO::MouseIO;
   else if(Prefs::input0key())   mode = KGameIO::KeyIO;
   else if(Prefs::input0ai())    mode = KGameIO::ProcessIO;
-  else kFatal() << "Unknown input device for player 0";
+  else qCCritical(KFOURINLINE_LOG) << "Unknown input device for player 0";
   if (global_demo_mode)         mode = KGameIO::ProcessIO;
   setPlayedBy(Yellow, mode);
-  kDebug() << "Played by Yellow="<<mode;  
+  qCDebug(KFOURINLINE_LOG) << "Played by Yellow="<<mode;  
   
   if(Prefs::input1mouse())      mode = KGameIO::MouseIO;
   else if(Prefs::input1key())   mode = KGameIO::KeyIO;
   else if(Prefs::input1ai())    mode = KGameIO::ProcessIO;
-  else kFatal() << "Unknown input device for player 1";
+  else qCCritical(KFOURINLINE_LOG) << "Unknown input device for player 1";
   if (global_demo_mode)         mode = KGameIO::ProcessIO;
   setPlayedBy(Red, mode);
-  kDebug() << "Played by Red="<<mode;  
+  qCDebug(KFOURINLINE_LOG) << "Played by Red="<<mode;  
 
   COLOUR col = Red;
   if (Prefs::startcolouryellow()) col = Yellow; 
 
   if (Prefs::startcolourred()) mStartPlayer.setValue(Red);
   else if (Prefs::startcolouryellow()) mStartPlayer.setValue(Yellow);
-  else kFatal() << "Unknown start color";
-  kDebug() << "Setting start player to" << mStartPlayer;
+  else qCCritical(KFOURINLINE_LOG) << "Unknown start color";
+  qCDebug(KFOURINLINE_LOG) << "Setting start player to" << mStartPlayer;
 
 
 }
@@ -748,7 +743,7 @@ void KWin4Doc::loadSettings()
 // Read config file
 void KWin4Doc::readConfig(KConfig *config)
 {
-  kDebug() << "++++++++++++++++++++++++++++++++++++ KWin4Doc::ReadConfig";
+  qCDebug(KFOURINLINE_LOG) << "++++++++++++++++++++++++++++++++++++ KWin4Doc::ReadConfig";
   loadSettings();
   
   KConfigGroup ygrp = config->group("YellowPlayer");
@@ -794,16 +789,16 @@ COLOUR KWin4Doc::switchStartPlayer()
     mStartPlayer.setValue(Red);
     Prefs::setStartcolouryellow(false);
     Prefs::setStartcolourred(true);
-    kDebug() << "Setting startplayer to RED";
+    qCDebug(KFOURINLINE_LOG) << "Setting startplayer to RED";
   }
   else
   {
     mStartPlayer.setValue(Yellow);
     Prefs::setStartcolouryellow(true);
     Prefs::setStartcolourred(false);
-    kDebug() << "Setting startplayer to YELLOW";
+    qCDebug(KFOURINLINE_LOG) << "Setting startplayer to YELLOW";
   }
-  Prefs::self()->writeConfig();
+  Prefs::self()->save();
   
   return (COLOUR)mStartPlayer.value();
 }
@@ -840,7 +835,7 @@ QString KWin4Doc::findProcessName()
     QFile fsrc(srcname);
     if (fsrc.exists())
     {
-      if (global_debug>1) kDebug() << "Found SRC_DIR process" << srcname;
+      if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Found SRC_DIR process" << srcname;
       return srcname;
     }
   #endif
@@ -851,21 +846,21 @@ QString KWin4Doc::findProcessName()
   QDir dir;
   // TODO: This local filename is not found!!
   QString filename=dir.path()+QString("/kwin4/kfourinlineproc");
-  kDebug() << "PROC FILENAME="<<filename;
+  qCDebug(KFOURINLINE_LOG) << "PROC FILENAME="<<filename;
   QFile flocal(filename);
   if (flocal.exists())
   {
-    if (global_debug>1) kDebug() << "Found local process" << filename;
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Found local process" << filename;
     return filename;
   }
-  QString path=KGlobal::mainComponent().dirs()->findExe("kfourinlineproc");
+  QString path= QStandardPaths::findExecutable("kfourinlineproc");
   if (!path.isNull())
   {
-    if (global_debug>1) kDebug() << "Found system process" << path;
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Found system process" << path;
     return path;
   }
   QString empty;
-  kError() <<  "Could not locate the computer player";
+  qCCritical(KFOURINLINE_LOG) <<  "Could not locate the computer player";
   return empty;
 }
 
@@ -873,7 +868,7 @@ QString KWin4Doc::findProcessName()
 // Debug: Listen to messages
 void KWin4Doc::networkMessageUpdate(int /*id*/,quint32 /*sender*/,quint32 /*recv*/)
 {
-//  kDebug(12010) << "MSG: id=" << id << "sender=" << sender << "receiver="<<recv;
+//  qCDebug(KFOURINLINE_LOG) << "MSG: id=" << id << "sender=" << sender << "receiver="<<recv;
 }
 
 
@@ -884,8 +879,7 @@ KPlayer *KWin4Doc::createPlayer(int /*rtti*/, int io, bool isvirtual)
   if (!isvirtual)
     createIO(player,(KGameIO::IOMode)io);
   
-  connect(player,SIGNAL(signalPropertyChanged(KGamePropertyBase*,KPlayer*)),
-          this,SLOT(playerPropertyChanged(KGamePropertyBase*,KPlayer*)));
+  connect(player, &KWin4Player::signalPropertyChanged, this, &KWin4Doc::playerPropertyChanged);
   player->setStatus(mStatus);
   return player;
 }
@@ -897,7 +891,7 @@ bool KWin4Doc::playerInput(QDataStream& msg, KPlayer* /*player*/)
 {
   qint32 move, pl;
   msg >> pl >> move;
-  kDebug() << "KWin4Doc::playerInput: ================ pl="<<pl<<" and move=" << move << "====================";
+  qCDebug(KFOURINLINE_LOG) << "KWin4Doc::playerInput: ================ pl="<<pl<<" and move=" << move << "====================";
 
   // Perform move and check for success
   if (!doMove(move,pl))
@@ -928,7 +922,7 @@ KGameIO::IOMode KWin4Doc::playedBy(int col)
 void KWin4Doc::setPlayedBy(int col, KGameIO::IOMode io)
 {
   if (global_debug>1)
-    kDebug(12010) << "  KWin4Doc::setPlayedBy(int "<<col<<",KGameIO::IOMode "<<io<<")";
+    qCDebug(KFOURINLINE_LOG) << "  KWin4Doc::setPlayedBy(int "<<col<<",KGameIO::IOMode "<<io<<")";
 
   KWin4Player *player=getPlayer((COLOUR)col);
 
@@ -963,43 +957,39 @@ void KWin4Doc::createIO(KPlayer* player, KGameIO::IOMode io)
     return;
   
   if (global_debug>1)
-    kDebug() << "KWin4Doc::createIO(KPlayer *player("<<player->userId()<<"),KGameIO::IOMode "<<io<<") ";
+    qCDebug(KFOURINLINE_LOG) << "KWin4Doc::createIO(KPlayer *player("<<player->userId()<<"),KGameIO::IOMode "<<io<<") ";
 
   if (io&KGameIO::MouseIO)
   {
     KGameMouseIO *input;
-    if (global_debug>1) kDebug() << "Creating MOUSE IO to "<<pView;
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Creating MOUSE IO to "<<pView;
     // We want the player to work over mouse. So please leave the "true" for mouse
     // tracking on !!!
     input=new KGameMouseIO(pView->viewport(), true);
-    if (global_debug>1) kDebug(12010) << "MOUSE IO added";
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "MOUSE IO added";
     // Connect mouse input to a function to process the actual input
-    connect(input,SIGNAL(signalMouseEvent(KGameIO*,QDataStream&,QMouseEvent*,bool*)),
-            pView,SLOT(mouseInput(KGameIO*,QDataStream&,QMouseEvent*,bool*)));
+    connect(input, &KGameMouseIO::signalMouseEvent, pView, &KWin4View::mouseInput);
     player->addGameIO(input);
   }
   else if (io&KGameIO::ProcessIO)
   {
     QString file=findProcessName();
-    if (global_debug>1) kDebug() << "Creating PROCESS IO" << file;
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Creating PROCESS IO" << file;
 
     KGameProcessIO *input;
     // We want a computer player
     input=new KGameProcessIO(file);
     // Connect computer player to the setTurn
-    connect(input,SIGNAL(signalPrepareTurn(QDataStream&,bool,KGameIO*,bool*)),
-            this,SLOT(prepareAITurn(QDataStream&,bool,KGameIO*,bool*)));
+    connect(input, &KGameProcessIO::signalPrepareTurn, this, &KWin4Doc::prepareAITurn);
 
-    connect(input,SIGNAL(signalProcessQuery(QDataStream&,KGameProcessIO*)),
-            this,SLOT(processAICommand(QDataStream&,KGameProcessIO*)));
+    connect(input, &KGameProcessIO::signalProcessQuery, this, &KWin4Doc::processAICommand);
 
-    connect(input,SIGNAL(signalReceivedStderr(QString)),
-            this,SLOT(receivedStderr(QString)));
+    connect(input, &KGameProcessIO::signalReceivedStderr, this, &KWin4Doc::receivedStderr);
     player->addGameIO(input);
   }
   else if (io&KGameIO::KeyIO)
   {
-    if (global_debug>1) kDebug() << "Creating KEYBOARD IO";
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Creating KEYBOARD IO";
     // We want the player to work over keyboard
     KGameKeyIO  *input;
     input=new KGameKeyIO(pView->parentWidget());
@@ -1013,7 +1003,7 @@ void KWin4Doc::createIO(KPlayer* player, KGameIO::IOMode io)
 void KWin4Doc::receivedStderr(const QString &s)
 {
   if (global_debug>0)
-    kDebug() << "##### AI:" << s;
+    qCDebug(KFOURINLINE_LOG) << "##### AI:" << s;
 }
 
 
@@ -1021,7 +1011,7 @@ void KWin4Doc::receivedStderr(const QString &s)
 void KWin4Doc::prepareAITurn(QDataStream& stream, bool b, KGameIO* input, bool* sendit)
 {
   if (global_debug>1)
-    kDebug(12010) << "KWin4Doc::prepareAITurn b="<<b;
+    qCDebug(KFOURINLINE_LOG) << "KWin4Doc::prepareAITurn b="<<b;
  
   // Set defaults
   *sendit = false;
@@ -1032,7 +1022,7 @@ void KWin4Doc::prepareAITurn(QDataStream& stream, bool b, KGameIO* input, bool*
   if (!b) return ; // only create move on setTurn(true)
 
   qint32 pl;
-  if (global_debug>1) kDebug(12010) << "slotPrepareComputerTurn for player id=" << player->id();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "slotPrepareComputerTurn for player id=" << player->id();
   pl=player->userId();
 
   // Pack the game into the message
@@ -1047,7 +1037,7 @@ void KWin4Doc::prepareAITurn(QDataStream& stream, bool b, KGameIO* input, bool*
 // player reading on the other side
 void KWin4Doc::prepareGameMessage(QDataStream& stream, qint32 pl)
 {
-  if (global_debug>1) kDebug(12010) << "          sending col=" << pl;
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "          sending col=" << pl;
   stream << pl ;
   // This needs to be the same than the computer player reads!
   stream << (qint32)getCurrentMove();
@@ -1064,7 +1054,8 @@ void KWin4Doc::prepareGameMessage(QDataStream& stream, qint32 pl)
   stream << (qint32)learning;
 
   // Where to save the learn cache
-  QString learnPath =  KGlobal::dirs()->saveLocation("data","kwin4",true);
+  QString learnPath =  QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "kwin4";
+
   stream << learnPath;
 
   int i,j;
@@ -1076,7 +1067,7 @@ void KWin4Doc::prepareGameMessage(QDataStream& stream, qint32 pl)
        col=getColour(j,i);
        stream << col;
     }
-    if (global_debug>1) kDebug(12010)
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG)
       << getColour(0,i)  << " "
       << getColour(1,i)  << " "
       << getColour(2,i)  << " "
@@ -1103,7 +1094,7 @@ void KWin4Doc::processAICommand(QDataStream& in, KGameProcessIO* io)
       AIBoard aiBoard;
       qint32 value, moveNo, level;
       in >> value >> moveNo >> level >> aiBoard;
-      if (global_debug>1) kDebug(12010) << "#### Computer thinks move" << moveNo << "value is" << value;
+      if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "#### Computer thinks move" << moveNo << "value is" << value;
       // Store AI data
       mAIValues[moveNo] = value;
       setScore(value);
@@ -1123,7 +1114,7 @@ void KWin4Doc::processAICommand(QDataStream& in, KGameProcessIO* io)
     }
     break;
     default:
-      kError() << "KWin4Doc::processAICommand: Unknown id" << cid;
+      qCCritical(KFOURINLINE_LOG) << "KWin4Doc::processAICommand: Unknown id" << cid;
     break;
   }
 }
@@ -1136,12 +1127,12 @@ void KWin4Doc::processAICommand(QDataStream& in, KGameProcessIO* io)
 // gameId() WE are the client
 void KWin4Doc::clientConnected(quint32 cid, KGame* /* me */)
 {
-  if (global_debug>1) kDebug(12010) << "void KWin4Doc::clientConnected id="<<cid << "we=" <<
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "void KWin4Doc::clientConnected id="<<cid << "we=" <<
   gameId() << "we admin=" << isAdmin() << "master)" << isMaster();
 
   if (playerList()->count()!=2)
   {
-    kError() << "SERIOUS ERROR: We do not have two players...Trying to disconnect!";
+    qCCritical(KFOURINLINE_LOG) << "SERIOUS ERROR: We do not have two players...Trying to disconnect!";
     disconnect();
     return ;
   }
@@ -1152,29 +1143,29 @@ void KWin4Doc::clientConnected(quint32 cid, KGame* /* me */)
   if (!p1->isVirtual())
   {
     emit signalChatChanged(p1);  
-    if (global_debug>1) kDebug(12010) << "CHAT to player 0";
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "CHAT to player 0";
   }
   else
   {
     emit signalChatChanged(p2);  
-    if (global_debug>1) kDebug(12010) << "CHAT to player 1";
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "CHAT to player 1";
   }
 
   // Now check whose turn it is. The Admin will rule this
   if (isAdmin())
   {
-    if (global_debug>1) kDebug(12010) << "WE are ADMIN == COOL ! ";
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "WE are ADMIN == COOL ! ";
     // p1 is local
     if (!p1->isVirtual())
     {
-      if (global_debug>1) kDebug(12010) << "p1 id=" << p1->userId() << "is local turn="<<p1->myTurn();
+      if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "p1 id=" << p1->userId() << "is local turn="<<p1->myTurn();
       // Exclusive setting of the turn
       p1->setTurn(p1->myTurn(),true);
       p2->setTurn(!p1->myTurn(),true);
     }
     else if (!p2->isVirtual())
     {
-      if (global_debug>1) kDebug(12010) << "p2 id=" << p2->userId() << "is local turn="<<p2->myTurn();
+      if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "p2 id=" << p2->userId() << "is local turn="<<p2->myTurn();
       // Exclusive setting of the turn
       p2->setTurn(p2->myTurn(),true);
       p1->setTurn(!p2->myTurn(),true);
@@ -1192,7 +1183,7 @@ KWin4Player* KWin4Doc::getPlayer(COLOUR col)
    if ((*it)->userId()==col)
      return (KWin4Player *)(*it);
  }
- kError() << "SERIOUS ERROR: Cannot find player with colour" << col << ".  CRASH imminent";
+ qCCritical(KFOURINLINE_LOG) << "SERIOUS ERROR: Cannot find player with colour" << col << ".  CRASH imminent";
  return 0;
 }
 
@@ -1204,13 +1195,12 @@ void KWin4Doc::calculateHint()
   if (!mHintProcess)
   {
     QString file = findProcessName();
-    if (global_debug>1) kDebug(12010) << "Creating HINT PROCESS";
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Creating HINT PROCESS";
 
     // We want a computer player
     mHintProcess=new KGameProcessIO(file);
 
-    connect(mHintProcess,SIGNAL(signalProcessQuery(QDataStream&,KGameProcessIO*)),
-            this,SLOT(processAIHintCommand(QDataStream&,KGameProcessIO*)));
+    connect(mHintProcess, &KGameProcessIO::signalProcessQuery, this, &KWin4Doc::processAIHintCommand);
   }
 
   // Send game to process
@@ -1238,8 +1228,8 @@ void KWin4Doc::processAIHintCommand(QDataStream& in,KGameProcessIO* /*io*/)
       qint32 value;
       // Read parameters of command
       in >>  pl >> move  >> value;
-      if (global_debug>1) kDebug(12010) << "#### Computer thinks pl=" << pl << "move =" << move;
-      if (global_debug>1) kDebug(12010) << "#### Computer thinks hint is" << move << "and value is" << value;
+      if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "#### Computer thinks pl=" << pl << "move =" << move;
+      if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "#### Computer thinks hint is" << move << "and value is" << value;
 
       // Display hint
       int x = move;
@@ -1248,7 +1238,7 @@ void KWin4Doc::processAIHintCommand(QDataStream& in,KGameProcessIO* /*io*/)
     }
     break;
     default:
-      kError() << "KWin4Doc::processAIHintCommand: Unknown id" << cid;
+      qCCritical(KFOURINLINE_LOG) << "KWin4Doc::processAIHintCommand: Unknown id" << cid;
     break;
   }
 }
@@ -1265,7 +1255,7 @@ void KWin4Doc::playerPropertyChanged(KGamePropertyBase* prop,KPlayer* player)
   // Check for name changes
   if (prop->id()==KGamePropertyBase::IdName)
   {
-    if (global_debug>1) kDebug(12010) << "Player name id=" << player->userId() << "changed to" << player->name();
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Player name id=" << player->userId() << "changed to" << player->name();
     mStatus->setPlayerName(player->name(),player->userId());
   }
 
@@ -1295,7 +1285,7 @@ void KWin4Doc::gamePropertyChanged(KGamePropertyBase* prop, KGame* /* me */)
    // Whose turn is it
    else if (prop->id()==mAmzug.id())
    {
-     if (global_debug>1) kDebug(12010) << "Amzug changed to" << mAmzug.value();
+     if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Amzug changed to" << mAmzug.value();
      mStatus->setTurn(mAmzug);
    }
 
@@ -1304,31 +1294,31 @@ void KWin4Doc::gamePropertyChanged(KGamePropertyBase* prop, KGame* /* me */)
    {
      if (gameStatus()==Abort)
      {
-       if (global_debug>1) kDebug(12010) << "PropertyChanged::status signal game abort +++";
+       if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "PropertyChanged::status signal game abort +++";
        emit signalGameOver(2,getPlayer(getCurrentPlayer()),this); // 2 indicates Abort
      }
      else if (gameStatus()==Run)
      {
-       if (global_debug>1) kDebug(12010) << "PropertyChanged::status signal game run +++";
+       if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "PropertyChanged::status signal game run +++";
        if (playerList()->count()==2)
        {
          activateCurrentPlayer(); // Set the current player to play
          emit signalGameRun();
        }
-       if (global_debug>1) kDebug(12010) << "PropertyChanged::status signal game run done +++";
+       if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "PropertyChanged::status signal game run done +++";
      }
      else if (gameStatus()==Init)
      {
-       if (global_debug>1) kDebug(12010) << "PropertyChanged::status signal game INIT +++";
+       if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "PropertyChanged::status signal game INIT +++";
        resetGame(true);
      }
      else if (gameStatus()==End)
      {
-       if (global_debug>1) kDebug(12010) << "PropertyChanged::status signal game END +++";
+       if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "PropertyChanged::status signal game END +++";
      }
      else
      {
-       if (global_debug>1) kDebug(12010) << "PropertyChanged::other status signal +++";
+       if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "PropertyChanged::other status signal +++";
      }
      
    }
@@ -1341,35 +1331,35 @@ void KWin4Doc::gamePropertyChanged(KGamePropertyBase* prop, KGame* /* me */)
 bool KWin4Doc::loadgame(QDataStream &stream,bool network,bool reset)
 {
   if (global_debug>1)
-    kDebug () << "loadgame() network=" << network << "reset="<< reset;
+    qCDebug(KFOURINLINE_LOG) << "loadgame() network=" << network << "reset="<< reset;
   if (!network) setGameStatus(End);
 
   // Clear out the old game 
-  if (global_debug>1) kDebug(12010)<<"loadgame wants to reset the game";
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG)<<"loadgame wants to reset the game";
   resetGame(true);
 
   // load the new game
   bool res=KGame::loadgame(stream,network,reset);
-  if (global_debug>1) kDebug(12010) << "amzug loaded to ="<<mAmzug.value();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "amzug loaded to ="<<mAmzug.value();
 
   // Replay the game be undoing and redoing
-  if (global_debug>1) kDebug(12010) << "REDRAW GAME using undo/redo";
-  if (global_debug>1) kDebug(12010) << "history cnt="<<mHistoryCnt.value();
-  if (global_debug>1) kDebug(12010) << "amzug ="<<mAmzug.value();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "REDRAW GAME using undo/redo";
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "history cnt="<<mHistoryCnt.value();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "amzug ="<<mAmzug.value();
   int cnt=0;
   while(undoMove())
   {
     cnt++;
-    if (global_debug>1) kDebug(12010) << "Undoing move "<<cnt;
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Undoing move "<<cnt;
   }
-  if (global_debug>1) kDebug(12010) << "amzug ="<<mAmzug.value();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "amzug ="<<mAmzug.value();
   while(cnt>0)
   {
     redoMove();
     cnt--;
-    if (global_debug>1) kDebug(12010) << "Redoing move "<<cnt;
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Redoing move "<<cnt;
   }
-  if (global_debug>1) kDebug(12010) << "amzug ="<<mAmzug.value();
+  if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "amzug ="<<mAmzug.value();
 
   // Set the input devices
   recalcIO();
@@ -1377,7 +1367,7 @@ bool KWin4Doc::loadgame(QDataStream &stream,bool network,bool reset)
   activateCurrentPlayer();
 
   if (global_debug>1)
-    kDebug(12010)  << "loadgame done +++";
+    qCDebug(KFOURINLINE_LOG)  << "loadgame done +++";
   return res;
 }
 
@@ -1390,7 +1380,7 @@ bool KWin4Doc::loadgame(QDataStream &stream,bool network,bool reset)
 void KWin4Doc::newPlayersJoin(KGamePlayerList* /*oldList*/,KGamePlayerList* newList,QList<int> &inactivate)
 {
   if (global_debug>1)
-    kDebug(12010) << "newPlayersJoin: START";
+    qCDebug(KFOURINLINE_LOG) << "newPlayersJoin: START";
   
   KWin4Player *yellow=getPlayer(Yellow);
   KWin4Player *red=getPlayer(Red);
@@ -1400,7 +1390,7 @@ void KWin4Doc::newPlayersJoin(KGamePlayerList* /*oldList*/,KGamePlayerList* newL
   {
     // Deactivate the lower one 
     inactivate.append(red->id());
-    if (global_debug>1) kDebug(12010) << "ADMIN keeps yellow and kicks red=" << red->id()<<" userId/col="<<red->userId();
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "ADMIN keeps yellow and kicks red=" << red->id()<<" userId/col="<<red->userId();
     // loop all client players and deactivate the one which have the color
     // yellow
     for ( KGamePlayerList::const_iterator it = newList->constBegin(); it != newList->constEnd(); it++ ) 
@@ -1409,7 +1399,7 @@ void KWin4Doc::newPlayersJoin(KGamePlayerList* /*oldList*/,KGamePlayerList* newL
       if (player->userId()==yellow->userId()) 
       {
         inactivate.append(player->id());
-        if (global_debug>1) kDebug(12010) << "Deactivate C1" << player->id()<<" col="<<player->userId();
+        if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Deactivate C1" << player->id()<<" col="<<player->userId();
       }
     }
   }
@@ -1417,7 +1407,7 @@ void KWin4Doc::newPlayersJoin(KGamePlayerList* /*oldList*/,KGamePlayerList* newL
   {
     // Deactivate the lower one 
     inactivate.append(yellow->id());
-    if (global_debug>1) kDebug(12010) << "ADMIN keeps red and kicks yellow=" << yellow->id()<<" userId/col="<<yellow->userId();
+    if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "ADMIN keeps red and kicks yellow=" << yellow->id()<<" userId/col="<<yellow->userId();
     // loop all client players and deactivate the one which have the color
     // red
     for ( KGamePlayerList::const_iterator it = newList->constBegin(); it != newList->constEnd(); it++ ) 
@@ -1426,12 +1416,12 @@ void KWin4Doc::newPlayersJoin(KGamePlayerList* /*oldList*/,KGamePlayerList* newL
       if (player->userId()==red->userId()) 
       {
         inactivate.append(player->id());
-        if (global_debug>1) kDebug(12010) << "Deactivate C2" << player->id()<<" col="<<player->userId();
+        if (global_debug>1) qCDebug(KFOURINLINE_LOG) << "Deactivate C2" << player->id()<<" col="<<player->userId();
       }
     }
   }
   if (global_debug>1)
-    kDebug(12010) << "newPlayersJoin: DONE";
+    qCDebug(KFOURINLINE_LOG) << "newPlayersJoin: DONE";
 }
 
-#include "kwin4doc.moc"
+
